@@ -1,5 +1,5 @@
 #' @title Kullback-Leibler R2
-#' @name r2_kl
+#' @name r2_kullback
 #'
 #' @description Calculates the Kullback-Leibler-divergence-based
 #'   R2 for generalized linear models.
@@ -11,12 +11,12 @@
 #'
 #' @examples
 #' model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
-#' r2_kl(model)
+#' r2_kullback(model)
 #'
 #' @references Cameron, A. C. and Windmeijer, A. G. (1997) An R-squared measure of goodness of fit for some common nonlinear regression models. Journal of Econometrics, 77: 329-342.
 #'
 #' @export
-r2_kl <- function(model, adjust = TRUE) {
+r2_kullback <- function(model, adjust = TRUE) {
   if (adjust)
     adj <- model$df.null / model$df.residual
   else
